% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% % function: ReadAFNIHead
% 
% % given the name of an AFNI HEAD
% 
% % file this function reads the 
% 
% % contents and returns information
% 
% % in a structure where the fields 
% 
% % are arranged as follows:
% 
% % contents of the structure are:
% 
% % headinfo.xdim ( x dimension size )
% 
% % headinfo.ydim ( y dimension size )
% 
% % headinfo.zdim ( z dimension size )
% 
% % headinfo.xvox ( x voxel size )
% 
% % headinfo.yvox ( y voxel size )
% 
% % headinfo.zvox ( z voxel size )
% 
% % headinfo.nvols ( number of sub-briks, i.e. for 3D+time )
% 
% % headinfo.orient ( orientation code, e.g. 351 )
% 
% % the orientation code is 3 numbers and corresponds to the following
% 
% % convention
% 
% % 0 = R-L
% 
% % 1 = L-R
% 
% % 2 = P-A
% 
% % 3 = A-P
% 
% % 4 = I-S
% 
% % 5 = S-I
% % $Id: ReadAFNIHead.m,v 1.2 2005/04/14 21:53:40 ybehzadi Exp $
% % 
% 
% % Timothy M. Ellmore (tellmore@nih.gov)
% 
% % Laboratory of Brain and Cognition
% 
% % National Institute of Mental Health



function headinfo =  ReadAFNIHead(hname)



fid=fopen(hname);

count = 1;

while 1

 line = fgetl(fid);

 if ~isstr(line), break, end

 

 if(strcmp('name  = DELTA',line))

  voxline = count + 2;

 end



 if(strcmp('name = DATASET_DIMENSIONS',line))

  dimline = count + 2;

 end



 if(strcmp('name = BRICK_TYPES',line))

  nvolsline = count + 1;

 end



 if(strcmp('name = ORIENT_SPECIFIC',line))

  orientline = count + 2;

 end



 % disp(line)

 count = count + 1;

end

fclose(fid);



fid=fopen(hname);

count = 1;

while 1

 line = fgetl(fid);

 if ~isstr(line), break, end

 

 if(count == voxline)

   voxinfo = sscanf(line,'%f %f %f');

 end



 if(count == dimline)

  diminfo = sscanf(line,'%d %d %d %d %d');

 end



 if(count == nvolsline)

  nvolsinfo = sscanf(line,'%s = %d');

 end



 if(count == orientline)

  orientinfo = sscanf(line,'%d %d %d');

 end

 

 count = count + 1;

end

fclose(fid);



headinfo.xdim = diminfo(1);

headinfo.ydim = diminfo(2);

headinfo.zdim = diminfo(3);

headinfo.xvox = abs(voxinfo(1));

headinfo.yvox = abs(voxinfo(2));

headinfo.zvox = abs(voxinfo(3));

headinfo.nvols = nvolsinfo(length(nvolsinfo));

headinfo.orient = orientinfo;



