function fmri=calcCBF(fbrik, CSFbrik, minconbrik, anatbrik)
%usage:  fmri=calcCBF(fbrik, CSFbrik, minconbrik, anatbrik)
%
% Input: 
%       fbrik:       functional brik name
%       CSFbrik:     CSF calibration brik name
%       minconbrik:  minimal contrast brik name
%       anatbrik:    anatomical brik name (optional)
% Output:
%       CBF maps
%
% Copyright (c) 2005 CUPID
% Author: Kun Lu     09/22/05
% History:
%  $Id: calcCBF.m,v 1.6 2007/03/20 22:01:30 jperthen Exp $
% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890\

CBF_globalvar

%--------------------------------------
% check and convert input parameters
%--------------------------------------
if ~iscell(fbrik)
    brikIn{1}=fbrik;
else
    brikIn=fbrik;
end

k=strfind(CSFbrik,'+orig');
if ~isempty(k)
   CSFbrik=CSFbrik(1:k(end)+4);
else
   CSFbrik=[CSFbrik '+orig'];
end

k=strfind(minconbrik,'+orig');
if ~isempty(k)
   minconbrik=minconbrik(1:k(end)+4);
else
   minconbrik=[minconbrik '+orig'];
end

if ~exist('anatbrik') | isempty(anatbrik)     
    doAnat=0; 
else
    doAnat=1;
end

if doAnat
    k=strfind(anatbrik,'+orig');
    if ~isempty(k)
        anatbrik=anatbrik(1:k(end)+4);
    else
        anatbrik=[anatbrik '+orig'];
    end
    change2RAI(anatbrik);
end


for i=1:length(brikIn)
    k=strfind(brikIn{i},'+orig');
    if ~isempty(k)
        brikIn{i}=brikIn{i}(1:k(end)+4);
    else
        brikIn{i}=[brikIn{i} '+orig'];
    end
end


%--------------------------------------
%initalize fmri structure
%--------------------------------------


warning off
fmri.flags.doCBF=1;
fmri.dir.data ='.';
fmri.study.name='.';
fmri.calib.minCon.name= minconbrik;
fmri.calib.minCon.params= NaN;
fmri.calib.CSF.name = CSFbrik;
fmri.calib.CSF.params=NaN;

for cntRun=1:length(brikIn)
    fmri.func(cntRun).name=brikIn{cntRun};
    fmri.func(cntRun).params.doCBF=1;
    fmri.func(cntRun).params.SIref='CSF';
    fmri.func(cntRun).params.im1=im1;

    fmri.func(cntRun).params=parseAFNIhead(fmri.func(cntRun).params,brikIn{cntRun},{'pulseSeq',...
        'TE','TI','TR','slDelay','FOV','voxSize','Rx'});

    fmri.func(cntRun).data.raw{1}=getBrik(fmri.func(cntRun).name,0);
    rData=fmri.func(cntRun).data.raw{1};
    fData=rData(:,:,:,fmri.func(cntRun).params.im1:end);

    fmri.func(cntRun).data.d3{1}= d3(fData);
end


%--------------------------------------
%  processing anatomical 
%--------------------------------------
if doAnat
    fmri.anat.name=anatbrik;
    fmri.flags.doAnat=1;
    fmri.anat.params.doSeg=3;
    fmri.anat.params.doReg=1;
    fmri.anat.params.funcRef=brikIn{1};
    fmri.anat.params.funcRx=fmri.func(1).params.Rx;
    fmri.anat.params = parseAFNIhead(fmri.anat.params,anatbrik,{'Rx'});
    fmri.anat.params.clockwise=-1;          
    fmri.anat.params.doRot=0;
    fmri.anat.params.rotName='default';
    fmri.anat.params.saveFullAnat=0;
    fmri.anat.params.betFrac=0.3;
    
    % do the BET and FAST
    fmri=processAnat(fmri);
end

%--------------------------------------
%  processing CBF 
%--------------------------------------
fmri=processCBF(fmri);

%--------------------------------------
%  Sanity check using gray matter mask values
%--------------------------------------
if doAnat
    gmMask=fmri.anat.gray>0.6;
    for i=1:length(fmri.func)
        CBFvals=nonzeros(gmMask.*fmri.func(i).data.CBF{1});

        CBFnz=CBFvals.*(CBFvals>-50 & CBFvals<250);
        histBins=[-96:6:252];
        N = HISTC(CBFnz,histBins);
        figure;bar(histBins,N);xlim([-50,250]);

        meanCBF=mean(CBFvals);
        stdCBF=std(CBFvals);
        title(sprintf('Histogram of gray matter CBF values:\nmean CBF=%.1f, std dev=%.1f',...
            meanCBF,stdCBF), 'FontSize', 14 );
        
    end
end

%--------------------------------------
% exporting CBF maps 
%--------------------------------------
disp('exporting CBF maps')

%exfields defined in globalvar.m

for i=1:length(fmri.func)
    refbrik=fmri.func(i).name(1:end-5);
    for j=1:length(exfields)
        brikOut=[refbrik '_' exfields{j}];
        V=eval(['fmri.func(i).data.' exfields{j},'{1}']);
        mat2brik([],V,brikOut,refbrik,1);
    end
end

