function change2RAI(brikName)
%usage: change2RAI(brikName)
% changes BRIK to RAI format, also Zero pads to square FOV if needed
%
% Input:
%    brikName   - brik file, (add +orig)
%                 e.g.: brikName='/home/krestom/data/051012hippo/anat+orig'
%
% Notes: original brik will be renamed with suffix '+nonRAI'
%
% Copyright (c) 2006 CUPID
% Author: kal
% History:
%  $Id: change2RAI.m,v 1.1 2006/01/26 19:34:06 krestom Exp $

% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890

%change name
if ~isRAI(brikName)
    str=sprintf('!mv %s.BRIK %s+orig.BRIK',brikName,[brikName(1:end-5),'+nonRAI']);eval(str);
    str=sprintf('!mv %s.HEAD %s+orig.HEAD',brikName,[brikName(1:end-5),'+nonRAI']);eval(str);
    %resample to RAI
    str=sprintf('!3dresample -prefix %s -orient RAI -dxyz 1.0 1.0 1.0 -inset %s',...
        [brikName(1:end-5),'+RAI'],[brikName(1:end-5),'+nonRAI+orig']);eval(str);
    %zero pad if needed, needed for OBlique_Reg
    str=sprintf('!3dZeropad -prefix %s -R 42 -L 42 -A 3 -P 3 -I 3 -S 3 %s',...
        brikName(1:end-5),[brikName(1:end-5),'+RAI+orig']);eval(str);
    %delete obsolete data
    str=sprintf('!rm -f %s*',[brikName(1:end-5),'+RAI+orig']);eval(str);
    %copy afni 3dNotes from original anat
    str = ['!3dNotes ',[brikName(1:end-5),'+nonRAI+orig'],' > AFNINotes'];eval(str);
    fid = fopen('AFNINotes');
    cntLine=1;
    while feof(fid) == 0
        tlineTemp=fgetl(fid);
        isNonNOTE = isempty(findstr(tlineTemp, 'NOTE'));
        if isNonNOTE;
            tline{cntLine} = tlineTemp;
            cntLine=cntLine+1;
        end
    end
    fclose(fid);
    str = ['!rm -f AFNINotes'];eval(str);
    NotesStr=[];
    for cntLine=1:length(tline)
        if cntLine==length(tline)
            NotesStr=[NotesStr,tline{cntLine}];
        else
            NotesStr=[NotesStr,'\n',tline{cntLine}];
        end
    end
    str=['!3dNotes -a "',NotesStr,'" ',brikName(1:end-5),'+orig'];eval(str);
end

function isTrue = isRAI(brikName)
%usage: isTrue = isRAI(brikName)
% checks if a brik is RAI
%
% Input:
%    brikName   - brik file, (add +orig)
%                 e.g.: brikName='/home/krestom/data/051012hippo/anat+orig'
%
% Copyright (c) 2004 CUPID
% Author: kal
% History:

% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890

stat=sprintf('!3dAttribute ORIENT_SPECIFIC %s > temp.txt',brikName);
eval(stat);
onum=load('temp.txt')+1;
ocode=['R' 'L' 'P' 'A' 'I' 'S'];
orient=[ocode(onum(1)) ocode(onum(2)) ocode(onum(3))];
isTrue = strcmp(orient,'RAI');
eval('!rm -f temp.txt');


