function ims(A,nCols,rnge,rotFlag,dispCB,showPnum,figTitle)
%usage: ims(A,nCols,rnge,rotFlag,dispCB,showPnum,figTitle)
% displays multi-page array data using imagesc within one figure
%
% Input:
%    A       - multi-page array
%    nCols   - number of columns to use with subplot, default = size(A,3)
%    rnge    - imagesc data range, default is what imagesc uses
%               - '1' autoscales, puts all plots on same scale
%    rotFlag - flag to rotate images before display
%    dispCB  - flag to display colormap, [1]
%    showPnum- flag to display slice number (or page number in matrix terms)
%    figTitle- text for figure title
%
% Output:
%    No Output
%
% Copyright (c) 2004 CUPID
% Author: kal
% History:
%  $Id: ims.m,v 1.8 2006/02/13 19:00:38 tomlab Exp $

% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890


if ~exist('nCols')      | isempty(nCols)        nCols=size(A,3);        end
if ~exist('rnge')       | isempty(rnge)         rnge=[];                end
if ~exist('rotFlag')    | isempty(rotFlag)      rotFlag=0;              end
if ~exist('dispCB')     | isempty(dispCB)       dispCB=1;               end
if ~exist('showPnum')   | isempty(showPnum)     showPnum=0;             end
if ~exist('figTitle')   | isempty(figTitle)     figTitle=[];            end

rgbFlag=0;
if ~rgbFlag
    ns=size(A,3);
else
    ns=size(A,4);
end

if rotFlag
    for cntSl=1:ns
        if ~rgbFlag
            A(:,:,cntSl)=rot90(A(:,:,cntSl),3);
        else
            for cntRGB=1:3
                A(:,:,cntRGB,cntSl)=rot90(A(:,:,cntRGB,cntSl),3);
            end
        end
    end
end

if rnge==1   % autoscale so all plots have same scale
    maxsc=max(max(max(A)));
    minsc=min(min(min(A)));
    rnge=[minsc,maxsc];
end
    
    
if ndims(rnge)==2
    rnge=repmat(rnge,[1 1 ns]);
end

sr=ceil(ns/nCols);
figure;
for cntPage=1:ns
    subplot(sr,nCols,cntPage);
    if isempty(rnge)
        if ~rgbFlag
            imagesc(A(:,:,cntPage));
        else
            imagesc(A(:,:,:,cntPage));
        end
    else
        if ~rgbFlag
            imagesc(A(:,:,cntPage),rnge(:,:,cntPage));
        else
            imagesc(A(:,:,:,cntPage),rnge(:,:,cntPage));
        end
    end
    axis('image');
    set(gca, 'XTickLabel', '');set(gca, 'YTickLabel', '');
    if showPnum title(num2str(cntPage)); end
    if dispCB colorbar('horiz'); end
end

if figTitle
    currFig=gcf;
    annotation1 = annotation(currFig,'textbox',...
        'Position',[0.2214 0.8167 0.5482 0.08571],'LineStyle','none',...
        'FitHeightToText','off','FontSize',12,...
        'HorizontalAlignment','center','String',{figTitle});
end

