function outIS = overlay2(underlay,overIm,opacity,underCmap,overCmap,numCol,cOrient,clim,figN)
% overlay2- plots avgerage of the data and an overlay
%
% Usage: outIS = overlay2(underlay,overIm,opacity,underCmap,overCmap,numCol,cOrient)
%        overlay2(underlay,overIm)
%        overlay2(underlay,overIm,.5,'gray','hot')
%
% Input:
%   overIm      - images to be overlayed
%   underlay    - image acting as underlay
%   opacity     - average data (default=0.5)
%   underCmap   - string corresponding to underlay colormap (default='gray')
%   overCmap    - string corresponding to underlay colormap (default='hot')
%   numCol      - number of colums to use for subplot of images, def =
%                 number of slice
%   cOrient     - colorBar orientaion, 1 - horiz, 2 - vertical, 3 - none, default=1
%   clim        - [clow chigh] clips overlay data at clow and chigh
%   figN        - used to display in a given figure and subplot #
%                      [figureNumber subplotRows subplotCols subplotNumber] 
%
% Output
%   outIS       - structure:
%                    - .imageRGB: RGB data of the image that is shown to you
%                    - .ticks: ticks on colorbar
%                    - .inds: ind on colorbar
%                    - .valsCell: vals for colorbar

% Copyright (c) 2004 CUPID
% Author: yashar      5/31/05
%$Id: overLay2.m,v 1.15 2006/06/22 23:30:50 tomlab Exp $
% End History:

% ruler --1234567890123456789012345678901234567890123456789012345678901234567890

numSlc=size(underlay,3);

if ~exist('opacity')    | isempty(opacity)      opacity=0.5;       end
if ~exist('underCmap')  | isempty(underCmap)    underCmap='gray';  end
if ~exist('overCmap')   | isempty(overCmap)     overCmap='hot';    end
if ~exist('numCol')     | isempty(numCol)       numCol=numSlc;     end
if ~exist('cOrient')    | isempty(cOrient)      cOrient=1;         end
if ~exist('clim')       | isempty(clim)         clim=[];           end

if numSlc~=numCol numRow=ceil(numSlc/numCol); else numRow=1; end

if ~isempty(clim) 
    %overIm=overIm.*(overIm>clim(1) & overIm<clim(2)); 
    overIm(overIm>clim(2))=clim(2);
    overIm=overIm.*(overIm>clim(1)); 
end

if ischar(overCmap)
    ticks       = 1:64;
    inds        = 1:20:64;
else
    ticks       = 1:size(overCmap,1);
    inds        = 1:size(overCmap,1);
end
%support for multislice added 050610, kal
if nargin==9
    figShown=figure(figN(1));
else
    figShown=figure;
end
rgbDataAll=[];
for cntSlice=1:numSlc
    [imageRGB,vals]        = sliceOverlay2(underlay(:,:,cntSlice),overIm(:,:,cntSlice),opacity,underCmap,overCmap);
    imageRGBcell{cntSlice} = imageRGB;
    valsCell{cntSlice}     = vals;

    figure(figShown);
    if nargin==9
        subplot(figN(2),figN(3),figN(4));
    else
        subplot(numRow,numCol,cntSlice);
    end
    image(imageRGBcell{cntSlice});
    axis('image');
    set(gca, 'XTickLabel', '');
    set(gca, 'YTickLabel', '');
    if ischar(overCmap)
        cmap=colormap(overCmap);
    else
        cmap=overCmap;
        cmap=colormap(overCmap);
    end
    switch cOrient
        case 1
            h= colorbar('horiz');
            set(h,'XTick',ticks(inds));
            set(h,'XTickLabel',num2str(valsCell{cntSlice}(inds)',2));
        case 2
            h= colorbar;
            set(h,'YTick',ticks(inds));
            set(h,'YTickLabel',num2str(valsCell{cntSlice}(inds)',2));
        case 3
            %do not show colorbar
    end
    rgbDataAll(:,:,:,cntSlice)=imageRGB;
end
imageRGB=[];imageRGB=cat(4,imageRGB,imageRGBcell{:});
outIS.imageRGB = imageRGB;
outIS.ticks    = ticks;
outIS.inds     = inds;
outIS.valsCell = valsCell;
outIS.rgbDataAll = rgbDataAll;
outIS.cmap       = cmap;

function [imageRGB,vals] = sliceOverlay2(underlay,overIm,opacity,underCmap,overCmap)

%get colormaps for the under and over images
figure;
underColor  = colormap(underCmap);
if ischar(overCmap)
    overColor   = colormap(overCmap);
else
    overColor=overCmap;
end
hh=gcf;
close(hh);

%by convention put into right orientation
underlay    = rot90(underlay,3);
overIm      = rot90(overIm,3);

sZ          = size(underlay);

%scale images from 1-64

%underlay
underV      = underlay(:);
underScale  = (underV-min(underV))./(max(underV)-min(underV));
if nnz((isnan(underScale))-ones(size(underScale)))==0      % avoids errors if this slice is all zeros on the underlay
    underScale=zeros(size(underScale));   
end
underScale  = round(63*underScale)+1;
underScale  = reshape(underScale,sZ);

%check to see if overIm is just two numbers, with min=0
binFlag = (length(unique(overIm))==2 & min(overIm(:))==0);

%check to see if overIm is all 0's
zeroFlag = (length(unique(overIm))==1 & min(overIm(:))==0);

%overIm
mask        = overIm~=0;
overV       = overIm(:);

%support for Binary or Zero data added 050606, Kal
if (~binFlag & ~zeroFlag)
    minV       = min(overIm(mask==1));
    maxV       = max(overIm(mask==1));
    overScale  = (overV-minV)./(maxV-minV);
    %form tick labels corresponding to image and scale of overIm
    vals        = linspace(minV,maxV,size(overColor,1));
elseif binFlag
    overScale  = (overV-min(overV))./(max(overV)-min(overV));
    %form tick labels corresponding to image and scale of overIm
    vals        = linspace(0,1,size(overColor,1));
elseif zeroFlag
    overScale  = zeros(size(overIm));
    vals        = linspace(0,0,size(overColor,1));
end
overScale  = round((size(overColor,1)-1)*overScale)+1;
overScale  = reshape(overScale,sZ);

if (~binFlag & ~zeroFlag) overScale(mask==0)=1; end

%make rgb matrices for the under and overIms
underRGB    = zeros(sZ(1), sZ(2), 3);
overRGB     = zeros(sZ(1), sZ(2), 3);

%map scaled images to colormap
%under
underRGB    = underColor(underScale(:),:);
%over
overRGB     = overColor(overScale(:),:);

%form overall images with opacity weighted overIm
%use binary mask.
%1- use weighted overIm
%0- use underlay
maskV       = mask(:);
imageRGB    = zeros(prod(sZ),3);

imageRGB(maskV==0,:)=...
    underRGB(maskV==0,:);
imageRGB(maskV==1,:)=...
    (1-opacity).*underRGB(maskV==1,:)+opacity.*overRGB(maskV==1,:);
imageRGB    = reshape(imageRGB,[sZ 3]);

















