function fmri=processAnat(fmri)
% processAnat - aligns anatomicals to functionals, strips brain, segments
%   brain into gray,white,and csf and finally creates downsampled binary
%   masks to be used later
% 
% Usage: fmri=processAnat(fmri)
% 
% Input:
%    fmri       - main strcuture used to get processing flags
%          .flags.doAnat
%          .anat.doRot
%          .anat.doReg
%          .anat.doSeg
%    
% 
% Output:
%    fmri.anat      - output with anat fields filled in
%           .raw
%           .full
%           .brain
%           .gray
%           .csf
%           .white
% 
% Restrictions:
%    1.
%    2.
% 
% Notes:
%    1. writes out bricks and fsl files to specified directory
%    2.
% 
% References:
%    1.
% 
% Examples:
%    1. [out11,out21,...] = test(in11,in21,...)
%           shows how to...
% 
%
% Copyright (c) 2004 CUPID
% Author: yashar      12/14/04
% $Id: processAnat.m,v 1.16 2006/07/21 16:58:50 jperthen Exp $

% ruler --1234567890123456789012345678901234567890123456789012345678901234567890
if fmri.flags.doAnat
    params      = fmri.anat(1).params;
    func_brik   = params.funcRef(1:end-5);
    func_Rx     = params.funcRx; 
    brikdir     = [fmri.dir.data,'/',fmri.study.name];
    anat_brik   = fmri.anat(1).name(1:end-5);
    anat_Rx     = params.Rx; 
    clockwise   = params.clockwise;  %yb 01/25/2005
    
    %**********************************************************************
    %register anatomical to specified functional
    if fmri.anat.params.doReg 
        %setup naming of output briks
        if strcmp(params.rotName,'default')
            if exist([brikdir '/processed'])~=7
                mkdir(brikdir,'processed');
            end
            out_brik = [brikdir,'/processed/',anat_brik,'+reg'];
        else
            out_brik    = [params.rotName];
        end
        
        if ispc %%yb 01/25/2005
%             eval(['cd ',fmri.dir.afni]); 
            rotAngle = Oblique_Reg(brikdir,func_brik,anat_brik,out_brik,func_Rx,anat_Rx,clockwise);
%             eval(['cd ',fmri.dir.home]); 
        else
            rotAngle = Oblique_Reg(brikdir,func_brik,anat_brik,out_brik,func_Rx,anat_Rx,clockwise);
        end
        fmri.anat(1).rotAngle = rotAngle;
        eval(['!3dresample -rmode Cu -master ',[brikdir,'/',func_brik,'+orig']...
                ' -prefix ',[out_brik,'+rs'],' -inset ',[out_brik,'+orig']]);
        
        ['Anatomical Data Set Rotated to Functional']
        
    else
        out_brik=fmri.anat.name;
    end
    %**********************************************************************

    %**********************************************************************
    %register volume to volume (alignment between two sessions)
    if fmri.anat.params.doRot 
        func_brik_rot   = params.funcAnatRef{1}(1:end-5);      
        outAnat      = [out_brik,'+rot'];       
        eval(['cd ',fmri.dir.afni]);
        %register the anatomical data sets
        eval(['!3dvolreg -verbose -twopass -twodup -clipit -zpad 4 -base ',...
                params.anatRef,' -prefix ',outAnat,' ',out_brik,'+orig']);
        eval(['cd ',fmri.dir.home]); 
        %rename anatomical to be segmented and resampled....
        out_brik=outAnat;    
        eval(['!3dresample -rmode Cu -master ',[func_brik_rot,'+orig']...
                ' -prefix ',[out_brik,'+rs'],' -inset ',[out_brik,'+orig']]);
               
    end
    %**********************************************************************

    %**********************************************************************
    %Segmentation of Anatomical data set
    seg             = params.doSeg;
    fmri.anat.raw   = getBrik([[out_brik,'+rs'],'+orig'],0);
    doOnlyLoad =  (fmri.flags.doAnat == 2);
    switch seg
        case 1
            fmri = processBet(fmri,doOnlyLoad);
        case 2
            fmri = processBet(fmri,doOnlyLoad);
            fmri = processFast(fmri,[],[],doOnlyLoad);
        case 3
            fmri = processFSL(fmri);     % does BET and FAST operations on rotated brain
    end
    %**********************************************************************

    %**********************************************************************
    %save full anatomical if you want...
    if params.saveFullAnat
        name=[brikdir,'/',fmri.anat(1).name];
        anat=getBrik(name,fmri.anat(1).params.doByteSwap);
        fmri.anat(1).full=anat;
    end
    %**********************************************************************
end