function fmri = processFSL(fmri)
%usage: fmri = processFSL(fmri)
% processFSL - performs BET and FAST on rotated anatomical
%
% Input:
%    fmri       - fmri structure used in cupid
%
% Output:
%    fmri        - fmri structure used in cupid (fmri.anat [.gray .white
%                  .csf] are created and are partial volume maps
%                  fmri.anat.brain also created
%
% Notes:
%    This is designed to replace processBet.m and processFast.m
%    Both BET and FAST are run on the anatomical AFTER registration to the
%    functional slices
%    compatibility with PCs not incorporated yet
%
% Copyright (c) 2004 CUPID
% Author: kal / yashar / jo
% History:
%  $Id: processFSL.m,v 1.8 2007/01/20 01:41:05 jperthen Exp $

% ruler
% --1234567890123456789012345678901234567890123456789012345678901234567890

%define some anat params
params      = fmri.anat(1).params;
doRot       = fmri.anat(1).params.doRot;
procName    = [fmri.dir.data ,'/',fmri.study.name,'/processed/'];

if doRot
    anatName    = [procName fmri.anat.name(1:end-5) '+reg+rot+orig'];
    str         = '+reg+rot+csf+pv+orig.BRIK';
else
    anatName    = [procName fmri.anat.name(1:end-5) '+reg+orig'];
    str         = '+reg+csf+pv+orig.BRIK';
end

if isnan(params.betFrac)
    betFrac=0.3;
else
    betFrac=params.betFrac;
end

pName=anatName(1:strfind(anatName,'processed')-1);

if exist([procName fmri.anat.name(1:end-5) str ])~=2
    loadOnly=0;
    %make anat FSL format
    try
        if ispc | ismac
            afni2fsl(anatName(1:end-5))
        else
            eval(['!afni2avw ' anatName]);
        end
    catch
        eval(['!afni2avw ' anatName]);
    end
    
    %extract skull
    eval(['!bet ' anatName '.hdr ' anatName(1:end-5) '+betonreg -f ' num2str(betFrac)]);
    %convert BET to BRIK
    eval(['!3dcopy ' anatName(1:end-5) '+betonreg.hdr' ' ' anatName(1:end-5) '+betonreg']);
    eval(['!3drefit -orient RAI -duporigin ' anatName ' ' anatName(1:end-5) '+betonreg+orig']);
    %reample BET to get fmri.anat.brain
    if doRot	% JP - resample to correct brik!!!
        eval(['!3dresample -rmode ''Li'' -master ' [fmri.anat(1).params.funcAnatRef{1}] ' -prefix ' anatName(1:end-5) '+betonreg+rs+orig' ' -inset ' anatName(1:end-5) '+betonreg+orig']);
    else
        eval(['!3dresample -rmode ''Li'' -master ' [pName,fmri.anat(1).params.funcRef] ' -prefix ' anatName(1:end-5) '+betonreg+rs+orig' ' -inset ' anatName(1:end-5) '+betonreg+orig']);
    end
    %run FSL FAST command on BET data
    eval(['!fast -i 8 -e -ov -os -od ' [anatName(1:end-5) '+segonreg'] ,' ', [anatName(1:end-5) '+betonreg.hdr']]);
else
    loadOnly=1;
end

%resample to functional and load in PV maps to fmri struct
fmri.anat.gray  = doRS(anatName,'gray',fmri,pName,loadOnly,doRot);
fmri.anat.white = doRS(anatName,'white',fmri,pName,loadOnly,doRot);
fmri.anat.csf   = doRS(anatName,'csf',fmri,pName,loadOnly,doRot);

fmri.anat.brain = getBrik([anatName(1:end-5) '+betonreg+rs+orig'],0,'int16')>40;

%remove all .hdr and .img files
if ~loadOnly
    eval(['!rm -f ' procName '*.hdr ']);eval(['!rm -f ' procName '*.img ']);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function segData = doRS(anatName,tType,fmri,pName,loadOnly,doRot)

switch tType;case 'gray';numT=1;case 'white';numT=2;case 'csf';numT=0;end
if ~loadOnly
    ev = sprintf('!3dcopy %s_pve_%d.hdr %s',[anatName(1:end-5) '+segonreg'],numT,[anatName(1:end-5) '+' tType '+pv']);
    eval(ev);
    ev = sprintf('!3drefit -orient RAI -duporigin %s %s+orig',anatName,[anatName(1:end-5) '+' tType '+pv']);
    eval(ev);
    if doRot
        ev = sprintf('!3dresample -rmode ''Li'' -master %s -prefix %s -inset %s',...
            [fmri.anat(1).params.funcAnatRef{1}],[anatName(1:end-5) '+' tType '+pv+rs'],...
            [anatName(1:end-5) '+' tType '+pv+orig']);
    else
        ev = sprintf('!3dresample -rmode ''Li'' -master %s -prefix %s -inset %s',...
            [pName,fmri.anat(1).params.funcRef],[anatName(1:end-5) '+' tType '+pv+rs'],...
            [anatName(1:end-5) '+' tType '+pv+orig']);
    end
    eval(ev);
end
segData=getBrik([anatName(1:end-5) '+' tType '+pv+rs+orig'],0,'float');
