function sfit=surfFit(T, lorder);
%usage: sfit=surfFit(T, lorder)
% surfFit - creates a surface fit
%
% Input:
%    T  - 2D dataset to be surface fitted
%    lorder - number of legendre polynomials to use
%
% Output:
%    sfit - fitted surface
%
% Copyright (c) 2005 CUPID
% Author: krestom
% History:
%  $Id: surfFit.m,v 1.2 2005/05/18 18:05:45 ybehzadi Exp $

% ruler --1234567890123456789012345678901234567890123456789012345678901234567890

nRows=size(T,1);
for row=1:nRows
    ts=T(row,:)';
    inds=find(ts);
    ts=ts(inds);
    A=legendremat(lorder,length(ts));
    rfit(row,:)=zeros(nRows,1)';
    rfit(row,inds)=(A*(A\ts))';
end

nCols=size(T,2);
for col=1:nCols
    ts=T(:,col);
    inds=find(ts);
    ts=ts(inds);
    A=legendremat(lorder,length(ts));
    cfit(:,col)=zeros(nCols,1);
    cfit(inds,col)=A*(A\ts);
end

nDr=size(T,2)-10;
drfit=zeros(size(T));
for dr=-nDr:nDr
    ts=diag(T,dr);
    drtemp=diag(ones(1,length(ts)),dr);
    drfitts=zeros(1,length(ts));
    diagInds=find(drtemp);
    inds=find(ts);
    ts=ts(inds);
    A=legendremat(lorder,length(ts));
    drfitts(inds)=A*(A\ts);
    drfit(diagInds)=drfitts;
end

nDl=size(T,2)-10;
Ttemp=flipud(T);
dlfit=zeros(size(Ttemp));
for dl=-nDl:nDl
    ts=diag(Ttemp,dl);
    dltemp=diag(ones(1,length(ts)),dl);
    dlfitts=zeros(1,length(ts));
    diagInds=find(dltemp);
    inds=find(ts);
    ts=ts(inds);
    A=legendremat(lorder,length(ts));
    dlfitts(inds)=A*(A\ts);
    dlfit(diagInds)=dlfitts;
end
dlfit=flipud(dlfit);

sfit=cat(3,rfit,cfit);
sfit=cat(3,sfit,drfit);
sfit=cat(3,sfit,dlfit);
sfit=mean(sfit,3);
sfit(isnan(sfit))=0;
%figure;imagesc(T);figure;imagesc(rfit);figure;imagesc(cfit);figure;imagesc(drfit);figure;imagesc(dlfit);figure;imagesc(sfit);
%figure;imagesc(T);
% figure;imagesc(sfit);
% figure;subplot(1,2,1);plot(T(32,:));xlim([0 65]);hold on; plot(sfit(32,:), 'r--');
% subplot(1,2,2);plot(T(:,32));xlim([0 65]);hold on;
% plot(sfit(:,32),'r--');

